# Export
export(TukeyC)
export(plot.TukeyC)
export(print.TukeyC)
export(summary.TukeyC)
export(boxplot.TukeyC)
export(cv)
export(xtable.TukeyC)
export(xtable)

# Import all packages listed as Imports or Depends
importFrom(emmeans, emmeans)
#importFrom(xtable, print.xtable)
importFrom(xtable, xtable)
import(
 utils,
 stats,
 graphics
)

# S3 methods
S3method(TukeyC, default)
S3method(TukeyC, formula)
S3method(TukeyC, lm)
S3method(TukeyC, aovlist)
S3method(TukeyC, lmerMod)
S3method(TukeyC, nest.lm)
S3method(TukeyC, nest.aovlist)
S3method(TukeyC, nest.lmerMod)
S3method(summary, TukeyC)
S3method(print, TukeyC)
S3method(xtable,TukeyC)
S3method(print,xtable.TukeyC)
S3method(plot, TukeyC)
S3method(boxplot, TukeyC)
